summaryrefslogtreecommitdiff
path: root/sw/qa/core/macros-test.cxx
diff options
context:
space:
mode:
authorRobinson Tryon <qubit@runcibility.com>2015-11-25 06:03:10 -0500
committerRobinson Tryon <qubit@runcibility.com>2015-11-25 06:07:38 -0500
commit49c2b9808df8a6b197dec666dfc0cda6321a4306 (patch)
tree045ef4b9b8dfdb06bfbe18cdf773d59f57d5552d /sw/qa/core/macros-test.cxx
parent5470a365f25e5052b4dd74f76aa2196f0d70934b (diff)
bin/rename-sw-abbreviations.sh libreoffice-5-1-branch-point
This commit renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I77e5134f42f25e3786afa36b7a505c7e3237a9e8
Diffstat (limited to 'sw/qa/core/macros-test.cxx')
-rw-r--r--sw/qa/core/macros-test.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/qa/core/macros-test.cxx b/sw/qa/core/macros-test.cxx
index 2223fd7e752f..6787d4f707bc 100644
--- a/sw/qa/core/macros-test.cxx
+++ b/sw/qa/core/macros-test.cxx
@@ -439,8 +439,8 @@ void SwMacrosTest::testFindReplace()
CPPUNIT_ASSERT(pTextDoc);
SwDoc *const pDoc = pTextDoc->GetDocShell()->GetDoc();
SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
- // use a UnoCrsr so it will be corrected when deleting nodes
- auto pPaM(pDoc->CreateUnoCrsr(SwPosition(aIdx)));
+ // use a UnoCursor so it will be corrected when deleting nodes
+ auto pPaM(pDoc->CreateUnoCursor(SwPosition(aIdx)));
IDocumentContentOperations & rIDCO(pDoc->getIDocumentContentOperations());
rIDCO.InsertString(*pPaM, "foo");